"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const persist_1 = require("./persist");
const alreadySaving = {};
const redoSearch = {};
const tryToSaveStore = (storage, store) => {
    const doSave = () => __awaiter(this, void 0, void 0, function* () {
        if (alreadySaving[store.name]) {
            redoSearch[store.name] = true;
            return;
        }
        alreadySaving[store.name] = true;
        yield persist_1.default(storage, [store]);
        alreadySaving[store.name] = false;
        if (redoSearch[store.name]) {
            redoSearch[store.name] = false;
            doSave();
        }
    });
    return doSave;
};
/**
 * Subscribe to `store` with the optional `key` param.
 * Calls `persist` for the store after every `resub` trigger relevant to `key`.
 * @param storage pass localforage or AsyncStorage here
 * @param store pass your IPersistableStore that should be persisted on change
 * @param key define to which `resub`-keys the autosave should react
 */
const autoSave = (storage, store, key) => {
    const s = store;
    return s.subscribe(tryToSaveStore(storage, store), key);
};
exports.default = autoSave;
//# sourceMappingURL=autoSave.js.map