"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get = require("lodash.get");
const set = require("lodash.set");
/**
 * Get a snapshot of the current store state.
 * Useful for testing with jest expect.toMatchSnapshot
 * If `paths` is omitted will use `store.getPropKeys`
 * @param store Store to create State-Snapshot from
 * @param paths (Optional) Only copy these strings (uses lodash.get/set)
 */
const getStoreState = (store, paths) => {
    const objectToMatch = {};
    const pathsToUse = paths !== undefined && Array.isArray(paths) ? paths : store.getPropKeys();
    for (const path of pathsToUse) {
        const val = get(store, path);
        set(objectToMatch, path, val);
    }
    return objectToMatch;
};
exports.default = getStoreState;
//# sourceMappingURL=getStoreState.js.map